#ifndef IMAGEPROCESSOR_H
#define IMAGEPROCESSOR_H
#include <QObject>
#include <QString>

class ImageProcessorPrivate;
class ImageProcessor : public QObject
{
    Q_OBJECT
    Q_ENUMS(ImageAlgorithm)
    Q_PROPERTY(QString sourceFile READ sourceFile)
    Q_PROPERTY(ImageAlgorithm algorithm READ algorithm)

public:
    ImageProcessor(QObject *parent = 0);
    ~ImageProcessor();

    //用于外引的enum变量，注意这个AlgorithmCount的使用
    enum ImageAlgorithm{
        Gray = 0,
        Binarize,
        Emboss,
        AlgorithmCount
    };

    //获得处理图片的地址
    QString sourceFile() const;
    //当前使用什么算法
    ImageAlgorithm algorithm() const;
    //设置temp地址
    void setTempPath(QString tempPath);

    //信号
signals:
    void finished(QString newFile);
    void progress(int value);

    //槽
public slots:
    void process(QString file, ImageAlgorithm algorithm);
    void abort(QString file, ImageAlgorithm algorithm);
    void abortAll();

private:
    ImageProcessorPrivate *m_d;
};

#endif // IMAGEPROCESSOR_H
